/******************************************************************************
* Tree Menu: This file defines the objects and functions needed to create a   *
* menu and display it in a child frame.                                       *
******************************************************************************/

//----------------------------------------------------------------------------
// Define the TreeMenuItem object.
//----------------------------------------------------------------------------

// Global index variable.

var treeMenuIndex = 0;

// Constructor.

function TreeMenuItem(text, url, target, icon, type)
{

  this.text = text;
  this.done=false;
  if(type) this.type = type;	
  else this.type="";
  if (url)this.url = url;
  else  this.url = "";
  
  if(this.type=="WindowCaption") this.url="";
  else if(this.type=="Branch") this.url="";
  
  if (target)  this.target = target;
  else  this.target = "";
  if (icon)  this.icon = icon;
  else  this.icon = "";

  this.submenu = null;
  this.parentMenu = null;
  this.index = treeMenuIndex++;
  this.makeSubmenu = TreeMenuMakeSubmenu;
}

// Methods.

function TreeMenuMakeSubmenu(menu) {
	this.submenu = menu;
	this.submenu.parentItem = this;   
}

//----------------------------------------------------------------------------
// Define the TreeMenu object.
//----------------------------------------------------------------------------

// Constructor.

function TreeMenu()
{
  this.items = new Array();
  this.parentItem = null;
  this.addItem = treeMenuAddItem;
}

// Methods.

function treeMenuAddItem(item)
{
	item.parentMenu = this;
	this.items[this.items.length] = item;
}

//----------------------------------------------------------------------------
// Global variables used in drawing the menu.
//----------------------------------------------------------------------------

var treeMenuDocument;       // Handle to the menu frame document.
var treeMenuWidth;          // Menu width in pixels.
var treeMenuExpand;         // Array created from first cookie.
var treeMenuSelected;       // Index of selected menu item from other cookie.
var treeMenuSelectedFound;  // Indicates if we've displayed the selected item.
var treeMenuScrollX;        // Amount to scroll the window right, if needed.
var treeMenuScrollY;        // Amount to scroll the window down, if needed.
var treeMenuLastItem;       // Flag indicating if we are on a menu's last item.
var treeMenuDepth;          // Keeps track the current menu level.
var treeMenuBars;           // Keeps track of image placement from row to row.
var blnOpeningDoc = false;
var activeStepItem;
var blnFinished = false;

//----------------------------------------------------------------------------
// This function rewrites the menu document to display the menu.
//----------------------------------------------------------------------------

function treeMenuDisplay()
{
  if(blnOpeningDoc) 
	return;
  blnOpeningDoc = true;
  blnFinished = false;
  var i, cookie;

  // Get submenu expansion flags from cookie. If no cookie exists, set all to
  // false and remove any cookie for the selected item.

  cookie = getCookie(treeMenuName);
  if (!cookie)
  {
    treeMenuExpand = new Array();
    for (i = 0; i < treeMenuIndex; i++)
      treeMenuExpand[i] = 0;
    deleteCookie(treeMenuName + "-selected");
  }
  else
    treeMenuExpand = cookie.split(",");

  // Get selected menu item from cookie.

  cookie = getCookie(treeMenuName + "-selected");
  if (!cookie)
    treeMenuSelected = -1;
  else
    treeMenuSelected = cookie;

  // Set up reference to the menu document.

  treeMenuDocument = window.frames[treeMenuFrame].document;

  // Set global variables used to draw the menu.

  treeMenuDepth = 0;
  treeMenuBars = new Array();

  // Intialize scrolling data.

  treeMenuSelectedFound = false;
  treeMenuScrollX = 36;
  //treeMenuScrollY = 18;

  // Draw the menu.  
  
  if (document.images)
    treeMenuDocument.open("text/html", "replace");
  else
    treeMenuDocument.open("text/html");
  treeMenuDocument.writeln('<html>');
  treeMenuDocument.writeln('<head>');
  treeMenuDocument.writeln('<meta http-equiv="Content-Type" content="text/html; charset='+ strCharset +'">');
  treeMenuDocument.writeln('<META HTTP-EQUIV="imagetoolbar" CONTENT="no">');
  treeMenuDocument.writeln('<title></title>');
  //treeMenuDocument.writeln('<style type="text/css">a {text-decoration:none;} all.selected {background-color:' + treeMenuHiBg + ';color:' + treeMenuHiFg + ';}</style>');
  treeMenuDocument.writeln('<style type="text/css">a {text-decoration:none;}</style>');
  treeMenuDocument.writeln('<SCRIPT LANGUAGE="JavaScript">');
  treeMenuDocument.writeln('<!--');
  treeMenuDocument.writeln('document.oncontextmenu=new Function("return false");');
  treeMenuDocument.writeln('//-->');
  treeMenuDocument.writeln('</SCRIPT>');
  treeMenuDocument.writeln('</head>');
  treeMenuDocument.writeln('<body bgcolor="' + treeMenuBgColor + '" text="' + treeMenuFgColor + '" link="' + treeMenuFgColor + '" alink="' + treeMenuFgColor + '" vlink="' + treeMenuFgColor + '" onLoad="if(document.layers) parent.treeMenuScroll();">');
  treeMenuDocument.writeln('<table border=0 cellpadding=0 cellspacing=0 width=' + treeMenuWidth + '>');
  
  //treeMenuDocument.writeln('<layer id="LHeader"><div id="DHeader" align="left">');
    
  treeMenuDocument.write('<tr valign=top><td>');
  treeMenuDocument.write('<img src="' + treeMenuImgDir + 'menu_root.gif" align=left border=0 vspace=0 hspace=0>');
  //treeMenuDocument.write('<a href="#" onClick="return parent.treeMenuClickRoot();">');
  //treeMenuDocument.write('<font face="MS Sans Serif,Arial,Helvetica" size=1>&nbsp;' + treeMenuRoot + '&nbsp;</font>');
  treeMenuDocument.write('&nbsp;' + treeMenuRoot + '&nbsp;');
  treeMenuDocument.writeln('</td><td width=50>&nbsp;' + strDoneMsg + '</td></tr>');
  //treeMenuDocument.writeln('</div></layer>');
  
  treeMenuListItems(treeMenu);
  treeMenuDocument.writeln('</table>');
  treeMenuDocument.writeln('</body>');  
  treeMenuDocument.writeln('</html>');
  treeMenuDocument.close();
  blnOpeningDoc=false;
  blnFinished = true;
  if(document.all){
	setTimeout("treeMenuScroll()", 50);
  }
}

//----------------------------------------------------------------------------
// This function displays each item in the given menu or submenu.
//----------------------------------------------------------------------------

function treeMenuListItems(menu) {

  var i;

  for (i = 0; i < menu.items.length; i++) {
    if (i == menu.items.length - 1)
      treeMenuLastItem = true;
    else
      treeMenuLastItem = false;
    treeMenuDisplayItem(menu.items[i]);
  }
}

//----------------------------------------------------------------------------
// This displays a single menu or submenu item.
//----------------------------------------------------------------------------

function treeMenuDisplayItem(item)
{

  var bars, cmd, expanded, i, img, link, more, submenu;  

  // If this item is a submenu, determine if should be expanded. For older
  // browsers, always expand.

  if (treeMenuExpand[item.index] == 1)
    expanded = true;
  else
    expanded = false;

  // Define the command used when an item is clicked. For older browsers, just
  // return true or false so links will be followed.

  if (item.submenu)
    submenu = true;
  else
    submenu = false;
  if (item.url != "")
    link = true;
  else
    link = false;
  cmd = "return parent.treeMenuClick(" + item.index + ", " + link + ", " + submenu + ", '" + item.url + "');";

  // Start the table row.
  var wOpener=window.opener; 
  if((typeof wOpener.strActiveStepUrl=='string')&& (wOpener!=null) && (item.url!="") &&(item.url==wOpener.strActiveStepUrl))
  {
	bgColor="#FFE7BD";
	activeStepItem=item;
	treeMenuSelected = item.index;
	setCookie(treeMenuName + "-selected", item.index, false);		
	treeMenuSelectedFound = true;
  }
  else if(item.type=="WindowCaption") 
	bgColor="#BBDFF9";
  else if(item.type=="Branch") 
	bgColor="#81F9F8";
  else 
	bgColor="#DBF7FB";

// Update vertical scrolling amount until we find the selected item.

  //if (item.index == treeMenuSelected)
  //  treeMenuSelectedFound = true;
 // if (!treeMenuSelectedFound)
 //		treeMenuScrollY += 10;
    
  treeMenuDocument.write('<tr valign=top  bgcolor='+bgColor+'><td>');

  // Draw descending bars from upper levels, also set horizontal scrolling
  // amount if this is the selected item.

  bars = new Array();
  for (i = 0; i < treeMenuDepth; i++) 
  {
    if (treeMenuBars[i]) 
    {
      treeMenuDocument.write('<img src="' + treeMenuImgDir + 'menu_bar.gif" align=left border=0 vspace=0 hspace=0>');
      bars[i] = true;
    }
    else 
    {
      treeMenuDocument.write('<img src="' + treeMenuImgDir + 'menu_pixel.gif" align=left border=0 vspace=0 hspace=0 width=18 height=18>');
      bars[i] = false;
    }
    if (item.index == treeMenuSelected)
      treeMenuScrollX += 10;
  }

  // Determine if this is a submenu item that contains other submenus.

  more = false;
  if (item.submenu)
    for (i = 0; i < item.submenu.items.length; i++)
      if (item.submenu.items[i].submenu != null)
        more = true;

  // Draw tee bar or corner if this item is not a submenu or if it is a
  // submenu but doesn't contain other submenus.

  if (!more) 
  {
    if (treeMenuLastItem) 
    {
      img = "menu_corner.gif";
      bars[bars.length] = false;
    }
    else 
    {
      img = "menu_tee.gif";
      bars[bars.length] = true;
    }
    treeMenuDocument.write('<img src="' + treeMenuImgDir + img + '" align=left border=0 vspace=0 hspace=0>');
  }  

  // For a submenu item that contains other submenus, draw a tee bar or corner
  // with a plus or minus sign.

  if(more) 
  {
    if(expanded) 
    {
      if (treeMenuLastItem) 
      {
        img = "menu_corner_minus.gif";
        bars[bars.length] = false;
      }
      else 
      {
        img = "menu_tee_minus.gif";
        bars[bars.length] = true;
      }
    }
    else
    {
      if (treeMenuLastItem)
      {
        img = "menu_corner_plus.gif";
        bars[bars.length] = false;
      }
      else
      {
        img = "menu_tee_plus.gif";
        bars[bars.length] = true;
      }
    }    
    var cmd2="return parent.treeMenuClick(" + item.index + ",false,"+ submenu + ", '" + item.url + "');";
    treeMenuDocument.write('<a href="#" onClick="' + cmd2 + ';"><img src="' + treeMenuImgDir + img + '" align=left border=0 vspace=0 hspace=0></a>');    
  }

	// Write the start of the link tag so all of the following images and text
	// will be clickable.

	if (item.url != "")
		treeMenuDocument.write('<a name="A' + item.index + '"  href="' + item.url + '" target="' + item.target + '" onClick="' + cmd + '">');
	else if(item.type=="WindowCaption") treeMenuDocument.write('<a name = "A' + item.index + '">');
	else treeMenuDocument.write('<a name = "A' + item.index + '" href="#" onClick="' + cmd + '">');
  
	// If the item is a submenu, draw an open or closed folder icon. Otherwise
	// draw a link icon.

	//if (item.submenu) {//Date 07/13 
		//if (expanded)// img = "menu_folder_open.gif";
		//else//Date 07/13 
		//img = "menu_folder_closed.gif";
	//}else {//Date 07/13 
		if (item.icon != "")
			img = item.icon;
		else if(item.type=="Step")
		{
		//Nguyen Van Binh - Version 1.04
			img = (item.index==treeMenuSelected)?"step_icon_active.gif":"step_icon.gif";
		}
		else if(item.type=="WindowCaption") img = "step_win_icon.gif";
		else if(item.type=="Branch") img = "branch_icon.gif";
		else
		{
		//Nguyen Van Binh - Version 1.04
			img = (item.index==treeMenuSelected)?"step_icon_active.gif":"step_icon.gif";
		}
	//}//Date 07/13 
	treeMenuDocument.write('<img src="' + treeMenuImgDir + img + '" align=left border=0 vspace=0 hspace=0>');

	// Write the link text and finish the link and table row.
	if (item.index == treeMenuSelected)
		treeMenuDocument.write('<font face=" lr oSVbN,MS Sans Serif,Arial,Helvetica" size=2 font-size:5pt><span class="selected">&nbsp;' + item.text + '&nbsp;</span></font>');
	else
		treeMenuDocument.write('<font face=" lr oSVbN,MS Sans Serif,Arial,Helvetica" size=2 font-size:5pt> ' + item.text + '</font>');
	treeMenuDocument.write('</a>');
	treeMenuDocument.writeln('</td>');
	treeMenuDocument.writeln('<td align=right>' + (item.done?'<img src='+treeMenuImgDir +'done_icon.gif>':'&nbsp;') + '</td>');
	treeMenuDocument.writeln('</tr>');

	// Set the placement of vertical bars needed for the next row.
	treeMenuBars = bars;

	// If the item is a submenu and it is expanded, make a recursive call to
	// draw its item list.

	if (item.submenu && expanded) {
		treeMenuDepth++;
		treeMenuListItems(item.submenu);
		treeMenuDepth--;
	}
}

//----------------------------------------------------------------------------
// This function handles a click on a menu item.
//----------------------------------------------------------------------------

function treeMenuClick(n, link, submenu, url) {

  var wOpener=window.opener;  
	if((typeof wOpener!='undefined') && (wOpener!=null) && (typeof wOpener.strActiveStepUrl=='string')) {
		//if(wOpener.isAuto)	return false;//not redraw and not link
		if(wOpener.isAuto)	return true;//02/10/15
	}
	
  var date, cookie;
  // Fix bug that occurs when the top-level page is reloaded.

  if (!treeMenuExpand)	treeMenuDisplay();

  // If this is a submenu, toggle the expansion flag.

  if (submenu&&(!link)) treeMenuExpand[n] = 1 - treeMenuExpand[n];

  // Update the cookies.
	
	if(treeMenuDays!=null){
		var date = new Date ();
		date.setTime (date.getTime() + (86400 * 1000 * treeMenuDays));		
	}
	cookie = treeMenuExpand.toString();
	setCookie(treeMenuName, cookie, date);
    setCookie(treeMenuName + "-selected", n, date);

    // Return the link flag.
	if(link){		
		if((typeof wOpener!='undefined') && (wOpener!=null) && (typeof wOpener.strActiveStepUrl=='string')) {			
			if(wOpener.isAuto)	return false;//not redraw and not link
			else wOpener.strActiveStepUrl=url;
		}else link = false;//opener window closed
	}
	
	// Set up redraw the menu frame.
  setTimeout("parent.treeMenuDisplay()", 10);

  return link;
}

//----------------------------------------------------------------------------
// This function handles a click on the menu root.
//----------------------------------------------------------------------------

function treeMenuClickRoot() {
  // Delete cookies.

  deleteCookie(treeMenuName);
  deleteCookie(treeMenuName + "-selected");

  // Set up redraw the menu frame.
  setTimeout("parent.treeMenuDisplay()", 10);

  return false;
}
function findAnchor(strAnchorName){
	var anchors = treeMenuDocument.anchors;
	for(var i = 0; i < anchors.length; i++){
		if(anchors[i].name == strAnchorName)
			return anchors[i];
	}
	return null;
}
//----------------------------------------------------------------------------
// This function scrolls the window to ensure the selected item is in view.
// It should only be called after the page has loaded.
//
// Note: This code is browser-dependent. Scrolling may be ignored for older
// browsers.
//----------------------------------------------------------------------------

function treeMenuScroll() {
  
  var win, height, width;
  // Get a handle to the window frame.

  win = window.frames[treeMenuFrame];
  // Find the dimensions of the window.
  if(typeof activeStepItem != 'object')
  	return;
  var activeAnchor = findAnchor ("A" + activeStepItem.index);
  var jg_n5 = (navigator.appName + parseInt(navigator.appVersion) == 'Netscape5');
   
  if (document.layers) {
    height = win.innerHeight;
    width = win.innerWidth;
    if(activeAnchor != null)
		treeMenuScrollY = activeAnchor.y - 16;    
  }else if (document.all) {
    height = win.document.body.clientHeight;
    width = win.document.body.clientWidth;	
	if(activeAnchor != null)
		treeMenuScrollY = activeAnchor.offsetParent.offsetTop;   	
  }else if (document.images) {
    win.scroll(0, treeMenuScrollY);
    return;
  }	else	return;
  
  // Scroll the window if necessary.

  //if (treeMenuScrollY > height)	
  win.scrollBy(0, treeMenuScrollY);
  //if (treeMenuScrollX > width)	win.scrollBy(treeMenuScrollX, 0);
}

//----------------------------------------------------------------------------
// Set a cookie given a name, value and expiration date.
//----------------------------------------------------------------------------

function setCookie (name, value, expires) {
	if(expires) document.cookie = name + "=" + escape(value) + "; expires=" + expires.toGMTString() +  "; path=/";
	else document.cookie = name + "=" + escape(value) + "; path=/";
}

//----------------------------------------------------------------------------
// Returns the value of the named cookie.
//----------------------------------------------------------------------------

function getCookie(name) {
	var search;
	search = name + "="
	offset = document.cookie.indexOf(search) 
	if (offset != -1) {
		offset += search.length ;
		end = document.cookie.indexOf(";", offset) ;
		if (end == -1)
		end = document.cookie.length;
		return unescape(document.cookie.substring(offset, end));
	}else	return "";
}

//----------------------------------------------------------------------------
// Delete the named cookie.
//----------------------------------------------------------------------------

function deleteCookie(name) {

	var expdate = new Date();
	expdate.setTime(expdate.getTime() - (86400 * 1000 * 1));
	setCookie(name, "", expdate);
}

function setDoneActiveStepItem(strNextUrl){
	if((typeof activeStepItem!='undefined')&&(activeStepItem!=null)){
		activeStepItem.done=true;
		expandActiveItem(activeStepItem, strNextUrl);
	}
}

function setUndoneMenu(menu){
	var i;
	for (i = 0; i < menu.items.length; i++) {
		menu.items[i].done=false;
		if(menu.items[i].submenu)
			setUndoneMenu(menu.items[i].submenu);
	}
}

function setUndoneAll(){
	setUndoneMenu(treeMenu);
}

function expandActiveItem(item, url){
	if(openBranch1(item, url)){
		treeMenuDisplay();//Redraw Tree menu.
	}
}

function isStepUrlInItemList(itemList, url, fromIndex){
	for (var i=fromIndex;i<itemList.length;i++){		
		if(itemList[i].url != "")
			if(itemList[i].url==url) return itemList[i];
			else return null;
	}
	return null;
}

function openBranch1(item, activeUrl){	
	var i, nextItem, blnChanged=false;
	nextItem = isStepUrlInItemList(item.parentMenu.items, activeUrl, item.index+1);
	if(nextItem!=null) {
		activeStepItem=nextItem;
		return false;
	}
	
	if(item.submenu){
		var subItemList = item.submenu.items;
		for(i=0;i<subItemList.length;i++){		
			if((subItemList[i].type=="Branch") 
				&& (typeof subItemList[i].submenu!='undefined')
				&& (typeof subItemList[i].submenu.items!='undefined')
				&& ((nextItem = isStepUrlInItemList (subItemList[i].submenu.items, activeUrl, 0))!=null) ){
					if(treeMenuExpand[item.index]==0||treeMenuExpand[subItemList[i].index]==0){
						treeMenuExpand[item.index] = 1;
						treeMenuExpand[subItemList[i].index] = 1;
						blnChanged=true;
					}
					activeStepItem=nextItem;
					break;
			}
		}
	}
	
	nextItem = item.parentMenu.parentItem;
	while(nextItem!=null && nextItem.parentMenu!=null){
		if(treeMenuExpand[nextItem.index]==0) {
			treeMenuExpand[nextItem.index] = 1; 
			blnChanged = true;
		}
		nextItem = nextItem.parentMenu.parentItem;
	}
	if(blnChanged){
		if(treeMenuDays!=null){
			var date = new Date ();
			date.setTime (date.getTime() + (86400 * 1000 * treeMenuDays));		
		}
	
		var cookie = treeMenuExpand.toString();
		setCookie(treeMenuName, cookie, date);
	}
	return blnChanged;
}

